@@ -4,7 +4,7 @@ from mohou.model.lstm import LSTMConfig
 from mohou.trainer import TrainConfig
 from mohou.dataset import AutoRegressiveDatasetConfig
 from mohou.default import create_default_embedding_rule
-from mohou.script_utils import train_lstm
+from mohou.script_utils import train_lstm, create_default_logger
 
 if __name__ == '__main__':
     parser = argparse.ArgumentParser()
@@ -23,6 +23,8 @@ if __name__ == '__main__':
     valid_ratio = args.valid_ratio
     warm_start = args.warm
 
+    logger = create_default_logger(project_name, 'lstm')  # noqa
+
     embedding_rule = create_default_embedding_rule(project_name)
     model_config = LSTMConfig(embedding_rule.dimension)
     dataset_config = AutoRegressiveDatasetConfig(n_aug, cov_scale=cov_scale)
