@@ -31,6 +31,8 @@ from mohou.trainer import TrainCache, TrainConfig, train
 from mohou.embedding_rule import EmbeddingRule
 from mohou.utils import canvas_to_ndarray
 
+logger = logging.getLogger(__name__)
+
 
 def create_default_logger(project_name: str, prefix: str) -> Logger:
     timestr = "_" + time.strftime("%Y%m%d%H%M%S")
@@ -61,8 +63,6 @@ def train_autoencoder(
         chunk: Optional[MultiEpisodeChunk] = None,
         warm_start: bool = False):
 
-    logger = create_default_logger(project_name, 'autoencoder')
-
     if chunk is None:
         chunk = MultiEpisodeChunk.load(project_name)
 
@@ -86,8 +86,6 @@ def train_lstm(
         chunk: Optional[MultiEpisodeChunk] = None,
         warm_start: bool = False):
 
-    logger = create_default_logger(project_name, 'lstm')  # noqa
-
     if chunk is None:
         chunk = MultiEpisodeChunk.load(project_name)
 
@@ -208,8 +206,8 @@ def visualize_lstm_propagation(project_name: str, propagator: Propagator, n_prop
         if use_gripper:
             pred_gss = [elem_dict[GripperState].numpy() for elem_dict in elem_dict_list]
 
-        n_av_dim = chunk.get_spec().type_shape_table[AngleVector][0]
-        n_gs_dim = chunk.get_spec().type_shape_table[GripperState][0] if use_gripper else 0
+        n_av_dim = chunk.spec.type_shape_table[AngleVector][0]
+        n_gs_dim = chunk.spec.type_shape_table[GripperState][0] if use_gripper else 0
         fig, axs = plt.subplots(n_av_dim + n_gs_dim, 1)
 
         # plot angle vectors
